==> ui-date-input-9.11.1.tgz: package/lib/DateInput2/__new-tests__/DateInput2.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard(require("react"));
var _react2 = require("@testing-library/react");
var _vitest = require("vitest");
var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
require("@testing-library/jest-dom");
var _index = require("../index");
var _DateInputExample, _DateInputExample2, _DateInputExample3;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
const LABEL_TEXT = 'Choose a date';
const DateInputExample = () => {
  const _useState = (0, _react.useState)(''),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    inputValue = _useState2[0],
    setInputValue = _useState2[1];
  return /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
    renderLabel: LABEL_TEXT,
    screenReaderLabels: {
      calendarIcon: 'Calendar',
      nextMonthButton: 'Next month',
      prevMonthButton: 'Previous month'
    },
    value: inputValue,
    onChange: (_e, inputValue, _dateString) => {
      setInputValue(inputValue);
    }
  });
};
describe('<DateInput2 />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution
    consoleWarningMock = _vitest.vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should render an input', async () => {
    const _render = (0, _react2.render)(_DateInputExample || (_DateInputExample = /*#__PURE__*/_react.default.createElement(DateInputExample, null))),
      container = _render.container;
    const dateInput = container.querySelector('input');
    expect(dateInput).toBeInTheDocument();
    expect(dateInput).toHaveAttribute('type', 'text');
  });
  it('should render an input label', async () => {
    const _render2 = (0, _react2.render)(_DateInputExample2 || (_DateInputExample2 = /*#__PURE__*/_react.default.createElement(DateInputExample, null))),
      container = _render2.container;
    const label = container.querySelector('label');
    expect(label).toBeInTheDocument();
    expect(label).toHaveTextContent(LABEL_TEXT);
  });
  it('should render an input placeholder', async () => {
    const placeholder = 'Placeholder';
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
      renderLabel: "Choose a date",
      screenReaderLabels: {
        calendarIcon: 'Calendar',
        nextMonthButton: 'Next month',
        prevMonthButton: 'Previous month'
      },
      placeholder: placeholder,
      value: ""
    }));
    const dateInput = _react2.screen.getByLabelText('Choose a date');
    expect(dateInput).toHaveAttribute('placeholder', placeholder);
  });
  it('should render a calendar icon with screen reader label', async () => {
    const iconLabel = 'Calendar icon Label';
    const _render3 = (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: "Choose a date",
        screenReaderLabels: {
          calendarIcon: iconLabel,
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: ""
      })),
      container = _render3.container;
    const calendarIcon = container.querySelector('svg[name="IconCalendarMonth"]');
    const calendarLabel = _react2.screen.getByText(iconLabel);
    expect(calendarIcon).toBeInTheDocument();
    expect(calendarLabel).toBeInTheDocument();
  });
  it('should not show calendar table by default', async () => {
    (0, _react2.render)(_DateInputExample3 || (_DateInputExample3 = /*#__PURE__*/_react.default.createElement(DateInputExample, null)));
    const calendarTable = _react2.screen.queryByRole('table');
    expect(calendarTable).not.toBeInTheDocument();
  });
  it('should render navigation arrow buttons with screen reader labels', async () => {
    const nextMonthLabel = 'Next month';
    const prevMonthLabel = 'Previous month';
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
      renderLabel: "Choose a date",
      screenReaderLabels: {
        calendarIcon: 'Calendar',
        nextMonthButton: nextMonthLabel,
        prevMonthButton: prevMonthLabel
      },
      value: ""
    }));
    const calendarButton = _react2.screen.getByRole('button');
    await _userEvent.default.click(calendarButton);
    await (0, _react2.waitFor)(() => {
      const prevMonthButton = _react2.screen.getByRole('button', {
        name: prevMonthLabel
      });
      const nextMonthButton = _react2.screen.getByRole('button', {
        name: nextMonthLabel
      });
      expect(prevMonthButton).toBeInTheDocument();
      expect(nextMonthButton).toBeInTheDocument();
      const prevButtonLabel = _react2.screen.getByText(prevMonthLabel);
      const nextButtonLabel = _react2.screen.getByText(nextMonthLabel);
      expect(prevButtonLabel).toBeInTheDocument();
      expect(nextButtonLabel).toBeInTheDocument();
      const prevMonthIcon = prevMonthButton.querySelector('svg[name="IconArrowOpenStart"]');
      const nextMonthIcon = nextMonthButton.querySelector('svg[name="IconArrowOpenEnd"]');
      expect(prevMonthIcon).toBeInTheDocument();
      expect(nextMonthIcon).toBeInTheDocument();
    });
  });
  it('should programmatically set and render the initial value', async () => {
    const value = '26/03/2024';
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
      renderLabel: "Choose a date",
      screenReaderLabels: {
        calendarIcon: 'Calendar',
        nextMonthButton: 'Next month',
        prevMonthButton: 'Previous month'
      },
      locale: "en-GB",
      timezone: "UTC",
      value: value
    }));
    const dateInput = _react2.screen.getByLabelText('Choose a date');
    expect(dateInput).toHaveValue(value);
    expect(dateInput).toBeInTheDocument();
  });
  it('should set interaction type to disabled', async () => {
    const interactionDisabled = 'disabled';
    const _render4 = (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: "Choose a date",
        screenReaderLabels: {
          calendarIcon: 'Calendar',
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: "",
        interaction: interactionDisabled
      })),
      container = _render4.container;
    const dateInput = container.querySelector('input');
    expect(dateInput).toHaveAttribute(interactionDisabled);
  });
  it('should set interaction type to readonly', async () => {
    const interactionReadOnly = 'readonly';
    const _render5 = (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: "Choose a date",
        screenReaderLabels: {
          calendarIcon: 'Calendar',
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: "",
        interaction: interactionReadOnly
      })),
      container = _render5.container;
    const dateInput = container.querySelector('input');
    const calendarButton = _react2.screen.getByRole('button');
    expect(dateInput).toHaveAttribute(interactionReadOnly);
    expect(calendarButton).toBeInTheDocument();
    await _userEvent.default.click(calendarButton);
    await (0, _react2.waitFor)(() => {
      const calendarTable = _react2.screen.queryByRole('table');
      expect(calendarTable).not.toBeInTheDocument();
    });
  });
  it('should set required', async () => {
    const _render6 = (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: "Choose a date",
        screenReaderLabels: {
          calendarIcon: 'Calendar',
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: "",
        isRequired: true
      })),
      container = _render6.container;
    const dateInput = container.querySelector('input');
    expect(dateInput).toHaveAttribute('required');
  });
  it('should call onBlur', async () => {
    const onBlur = _vitest.vi.fn();
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
      renderLabel: "Choose a date",
      screenReaderLabels: {
        calendarIcon: 'Calendar',
        nextMonthButton: 'Next month',
        prevMonthButton: 'Previous month'
      },
      value: "",
      onBlur: onBlur
    }));
    const dateInput = _react2.screen.getByLabelText('Choose a date');
    _react2.fireEvent.blur(dateInput);
    await (0, _react2.waitFor)(() => {
      expect(onBlur).toHaveBeenCalled();
    });
  });
  it('should validate if the invalidDateErrorMessage prop is provided', async () => {
    const errorMsg = 'errorMsg';
    const Example = () => {
      const _useState3 = (0, _react.useState)(''),
        _useState4 = (0, _slicedToArray2.default)(_useState3, 2),
        inputValue = _useState4[0],
        setInputValue = _useState4[1];
      return /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: LABEL_TEXT,
        screenReaderLabels: {
          calendarIcon: 'Calendar',
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: inputValue,
        onChange: (_e, inputValue, _dateString) => {
          setInputValue(inputValue);
        },
        invalidDateErrorMessage: errorMsg
      });
    };
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(Example, null));
    expect(_react2.screen.queryByText(errorMsg)).not.toBeInTheDocument();
    const dateInput = _react2.screen.getByLabelText(LABEL_TEXT);
    await _userEvent.default.click(dateInput);
    await _userEvent.default.type(dateInput, 'Not a date');
    dateInput.blur();
    await (0, _react2.waitFor)(() => {
      expect(_react2.screen.getByText(errorMsg)).toBeInTheDocument();
    });
  });
  it('should show form field messages', async () => {
    const messages = [{
      text: 'TypeLess'
    }, {
      type: 'error',
      text: 'Error'
    }, {
      type: 'success',
      text: 'Success'
    }, {
      type: 'hint',
      text: 'Hint'
    }, {
      type: 'screenreader-only',
      text: 'Screenreader'
    }];
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
      renderLabel: "Choose a date",
      screenReaderLabels: {
        calendarIcon: 'Calendar',
        nextMonthButton: 'Next month',
        prevMonthButton: 'Previous month'
      },
      value: "",
      messages: messages
    }));
    expect(_react2.screen.getByText('TypeLess')).toBeVisible();
    expect(_react2.screen.getByText('Error')).toBeVisible();
    expect(_react2.screen.getByText('Success')).toBeVisible();
    expect(_react2.screen.getByText('Hint')).toBeVisible();
    const screenreaderMessage = _react2.screen.getByText('Screenreader');
    expect(screenreaderMessage).toBeInTheDocument();
    expect(screenreaderMessage).toHaveClass(/screenReaderContent/);
  });
});

==> ui-date-input-10.16.0.tgz: package/lib/DateInput2/__new-tests__/DateInput2.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard(require("react"));
var _react2 = require("@testing-library/react");
var _vitest = require("vitest");
var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
require("@testing-library/jest-dom");
var _IconHeartLine2 = require("@instructure/ui-icons/lib/IconHeartLine.js");
var _index = require("../index");
var _DateInputExample, _DateInputExample2, _IconHeartLine, _DateInputExample3, _DateInputExample4;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
const LABEL_TEXT = 'Choose a date';
const DateInputExample = () => {
  const _useState = (0, _react.useState)(''),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    inputValue = _useState2[0],
    setInputValue = _useState2[1];
  return /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
    renderLabel: LABEL_TEXT,
    screenReaderLabels: {
      calendarIcon: 'Calendar',
      nextMonthButton: 'Next month',
      prevMonthButton: 'Previous month'
    },
    value: inputValue,
    onChange: (_e, inputValue, _dateString) => {
      setInputValue(inputValue);
    }
  });
};
describe('<DateInput2 />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution
    consoleWarningMock = _vitest.vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should render an input', async () => {
    const _render = (0, _react2.render)(_DateInputExample || (_DateInputExample = /*#__PURE__*/_react.default.createElement(DateInputExample, null))),
      container = _render.container;
    const dateInput = container.querySelector('input');
    expect(dateInput).toBeInTheDocument();
    expect(dateInput).toHaveAttribute('type', 'text');
  });
  it('should render an input label', async () => {
    const _render2 = (0, _react2.render)(_DateInputExample2 || (_DateInputExample2 = /*#__PURE__*/_react.default.createElement(DateInputExample, null))),
      container = _render2.container;
    const label = container.querySelector('label');
    expect(label).toBeInTheDocument();
    expect(label).toHaveTextContent(LABEL_TEXT);
  });
  it('should render an input placeholder', async () => {
    const placeholder = 'Placeholder';
    (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.DateInput2, {
      renderLabel: "Choose a date",
      screenReaderLabels: {
        calendarIcon: 'Calendar',
        nextMonthButton: 'Next month',
        prevMonthButton: 'Previous month'
      },
      placeholder: placeholder,
      value: ""
    }));
    const dateInput = _react2.screen.getByLabelText('Choose a date');
    expect(dateInput).toHaveAttribute('placeholder', placeholder);
  });
  it('should render a calendar icon with screen reader label', async () => {
    const iconLabel = 'Calendar icon Label';
    const _render3 = (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: "Choose a date",
        screenReaderLabels: {
          calendarIcon: iconLabel,
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: ""
      })),
      container = _render3.container;
    const calendarIcon = container.querySelector('svg[name="IconCalendarMonth"]');
    const calendarLabel = _react2.screen.getByText(iconLabel);
    expect(calendarIcon).toBeInTheDocument();
    expect(calendarLabel).toBeInTheDocument();
  });
  it('should render a custom calendar icon with screen reader label', async () => {
    const iconLabel = 'Calendar icon Label';
    const _render4 = (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: "Choose a date",
        screenReaderLabels: {
          calendarIcon: iconLabel,
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: "",
        renderCalendarIcon: _IconHeartLine || (_IconHeartLine = /*#__PURE__*/_react.default.createElement(_IconHeartLine2.IconHeartLine, null))
      })),
      container = _render4.container;
    const calendarIcon = container.querySelector('svg[name="IconHeart"]');
    const calendarLabel = _react2.screen.getByText(iconLabel);
    expect(calendarIcon).toBeInTheDocument();
    expect(calendarLabel).toBeInTheDocument();
  });
  it('should not show calendar table by default', async () => {
    (0, _react2.render)(_DateInputExample3 || (_DateInputExample3 = /*#__PURE__*/_react.default.createElement(DateInputExample, null)));
    const calendarTable = _react2.screen.queryByRole('table');
    expect(calendarTable).not.toBeInTheDocument();
  });
  it('should show calendar table when calendar button is clicked', async () => {
    (0, _react2.render)(_DateInputExample4 || (_DateInputExample4 = /*#__PURE__*/_react.default.createElement(DateInputExample, null)));
    const calendarButton = _react2.screen.getByRole('button');
    expect(calendarButton).toBeInTheDocument();
    await _userEvent.default.click(calendarButton);
    await (0, _react2.waitFor)(() => {
      const calendarTable = _react2.screen.queryByRole('table');
      expect(calendarTable).toBeInTheDocument();
    });
  });
  it('should render navigation arrow buttons with screen reader labels', async () => {
    const nextMonthLabel = 'Next month';
    const prevMonthLabel = 'Previous month';
    (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.DateInput2, {
      renderLabel: "Choose a date",
      screenReaderLabels: {
        calendarIcon: 'Calendar',
        nextMonthButton: nextMonthLabel,
        prevMonthButton: prevMonthLabel
      },
      value: ""
    }));
    const calendarButton = _react2.screen.getByRole('button');
    await _userEvent.default.click(calendarButton);
    await (0, _react2.waitFor)(() => {
      const prevMonthButton = _react2.screen.getByRole('button', {
        name: prevMonthLabel
      });
      const nextMonthButton = _react2.screen.getByRole('button', {
        name: nextMonthLabel
      });
      expect(prevMonthButton).toBeInTheDocument();
      expect(nextMonthButton).toBeInTheDocument();
      const prevButtonLabel = _react2.screen.getByText(prevMonthLabel);
      const nextButtonLabel = _react2.screen.getByText(nextMonthLabel);
      expect(prevButtonLabel).toBeInTheDocument();
      expect(nextButtonLabel).toBeInTheDocument();
      const prevMonthIcon = prevMonthButton.querySelector('svg[name="IconArrowOpenStart"]');
      const nextMonthIcon = nextMonthButton.querySelector('svg[name="IconArrowOpenEnd"]');
      expect(prevMonthIcon).toBeInTheDocument();
      expect(nextMonthIcon).toBeInTheDocument();
    });
  });
  it('should programmatically set and render the initial value', async () => {
    const value = '26/03/2024';
    (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.DateInput2, {
      renderLabel: "Choose a date",
      screenReaderLabels: {
        calendarIcon: 'Calendar',
        nextMonthButton: 'Next month',
        prevMonthButton: 'Previous month'
      },
      locale: "en-GB",
      timezone: "UTC",
      value: value
    }));
    const dateInput = _react2.screen.getByLabelText('Choose a date');
    expect(dateInput).toHaveValue(value);
    expect(dateInput).toBeInTheDocument();
  });
  it('should set interaction type to disabled', async () => {
    const interactionDisabled = 'disabled';
    const _render5 = (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: "Choose a date",
        screenReaderLabels: {
          calendarIcon: 'Calendar',
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: "",
        interaction: interactionDisabled
      })),
      container = _render5.container;
    const dateInput = container.querySelector('input');
    expect(dateInput).toHaveAttribute(interactionDisabled);
  });
  it('should set interaction type to readonly', async () => {
    const interactionReadOnly = 'readonly';
    const _render6 = (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: "Choose a date",
        screenReaderLabels: {
          calendarIcon: 'Calendar',
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: "",
        interaction: interactionReadOnly
      })),
      container = _render6.container;
    const dateInput = container.querySelector('input');
    const calendarButton = _react2.screen.getByRole('button');
    expect(dateInput).toHaveAttribute(interactionReadOnly);
    expect(calendarButton).toBeInTheDocument();
    await _userEvent.default.click(calendarButton);
    await (0, _react2.waitFor)(() => {
      const calendarTable = _react2.screen.queryByRole('table');
      expect(calendarTable).not.toBeInTheDocument();
    });
  });
  it('should set required', async () => {
    const _render7 = (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: "Choose a date",
        screenReaderLabels: {
          calendarIcon: 'Calendar',
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: "",
        isRequired: true
      })),
      container = _render7.container;
    const dateInput = container.querySelector('input');
    expect(dateInput).toHaveAttribute('required');
  });
  it('should call onBlur', async () => {
    const onBlur = _vitest.vi.fn();
    (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.DateInput2, {
      renderLabel: "Choose a date",
      screenReaderLabels: {
        calendarIcon: 'Calendar',
        nextMonthButton: 'Next month',
        prevMonthButton: 'Previous month'
      },
      value: "",
      onBlur: onBlur
    }));
    const dateInput = _react2.screen.getByLabelText('Choose a date');
    _react2.fireEvent.blur(dateInput);
    await (0, _react2.waitFor)(() => {
      expect(onBlur).toHaveBeenCalled();
    });
  });
  it('should validate if the invalidDateErrorMessage prop is provided', async () => {
    const errorMsg = 'errorMsg';
    const Example = () => {
      const _useState3 = (0, _react.useState)(''),
        _useState4 = (0, _slicedToArray2.default)(_useState3, 2),
        inputValue = _useState4[0],
        setInputValue = _useState4[1];
      return /*#__PURE__*/_react.default.createElement(_index.DateInput2, {
        renderLabel: LABEL_TEXT,
        screenReaderLabels: {
          calendarIcon: 'Calendar',
          nextMonthButton: 'Next month',
          prevMonthButton: 'Previous month'
        },
        value: inputValue,
        onChange: (_e, inputValue, _dateString) => {
          setInputValue(inputValue);
        },
        invalidDateErrorMessage: errorMsg
      });
    };
    (0, _react2.render)(/*#__PURE__*/_react.default.createElement(Example, null));
    expect(_react2.screen.queryByText(errorMsg)).not.toBeInTheDocument();
    const dateInput = _react2.screen.getByLabelText(LABEL_TEXT);
    await _userEvent.default.click(dateInput);
    await _userEvent.default.type(dateInput, 'Not a date');
    dateInput.blur();
    await (0, _react2.waitFor)(() => {
      expect(_react2.screen.getByText(errorMsg)).toBeInTheDocument();
    });
  });
  it('should show form field messages', async () => {
    const messages = [{
      text: 'TypeLess'
    }, {
      type: 'error',
      text: 'Error'
    }, {
      type: 'success',
      text: 'Success'
    }, {
      type: 'hint',
      text: 'Hint'
    }, {
      type: 'screenreader-only',
      text: 'Screenreader'
    }];
    (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.DateInput2, {
      renderLabel: "Choose a date",
      screenReaderLabels: {
        calendarIcon: 'Calendar',
        nextMonthButton: 'Next month',
        prevMonthButton: 'Previous month'
      },
      value: "",
      messages: messages
    }));
    expect(_react2.screen.getByText('TypeLess')).toBeVisible();
    expect(_react2.screen.getByText('Error')).toBeVisible();
    expect(_react2.screen.getByText('Success')).toBeVisible();
    expect(_react2.screen.getByText('Hint')).toBeVisible();
    const screenreaderMessage = _react2.screen.getByText('Screenreader');
    expect(screenreaderMessage).toBeInTheDocument();
    expect(screenreaderMessage).toHaveClass(/screenReaderContent/);
  });
});
